require 'acceptance_helpers'
require 'shared/examples'
require 'shared/contexts'

resource 'Collections' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:collection) } }

  it_behaves_like "get a list", '/v1/collections', Collection, 'collections'
  let(:collections) { Collection.all }
  #
  # get '/v1/collections' do
  #   parameter :limit, 'Limit of collections'
  #   parameter :offset, 'Offset of collections'
  #
  #   let(:limit) { 12 }
  #   let(:offset) { 0 }
  #
  #   example_request 'Get a list of collections' do
  #     expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(Collection.limit(limit).offset(offset).pluck(:id).sort)
  #     expect(status).to eq(200)
  #   end
  # end

  get '/v1/collections/:id' do
    let(:id) { collections.first.id }

    example 'Get a collection' do
      do_request
      expect(path).to eq("/v1/collections/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(Collection.find(id)))
      expect(status).to eq(200)
    end
  end

  post '/v1/collections/:id/like' do
    include_context "authenticate_user"

    let(:id) { collections.first.id }

    example 'Liking a collection' do
      likes = collections.first.likes.count
      do_request
      expect(path).to eq("/v1/collections/#{id}/like")
      expect(JSON.parse(response_body)['count']).to eq(likes + 1)
      expect(status).to eq(201)
    end
  end

  delete '/v1/collections/:id/like' do
    include_context "authenticate_user"

    let(:id) { collections.first.id }

    before do
      create(:like, user: @user, likeable: collections.first)
    end

    example 'Unliking a collection' do
      likes = collections.first.likes.count
      do_request
      expect(path).to eq("/v1/collections/#{id}/like")
      expect(JSON.parse(response_body)['count']).to eq(likes - 1)
      expect(status).to eq(200)
    end
  end




end
